module read_grid_m

  implicit none

  integer, protected:: nlon = - 1, nlat = - 1
  ! size of ssh array in input NetCDF, assuming no repeated point if
  ! the grid is global

  logical, protected:: periodic ! grid is periodic in longitude

  real, protected:: corner(2)
  ! longitude and latitude of the corner of the whole grid in input
  ! NetCDF, in rad

  real, protected:: step(2) ! longitude and latitude steps, in rad

contains

  subroutine read_grid(rank, shpc_dir)

    ! Libraries:
#ifndef CPP_SEQUENTIAL
    use ezmpi, only: ezmpi_bcast
#endif
    use jumble, only: new_unit, deg_to_rad

    integer, intent(in):: rank
    character(len = *), intent(in):: shpc_dir

    ! Local:

    integer unit

    real:: corner_deg(2) = [huge(0.), huge(0.)]
    ! longitude and latitude of the corner of the whole grid in input
    ! NetCDF, in degrees

    real:: step_deg(2) = [huge(0.), huge(0.)]
    ! longitude and latitude steps, in degrees

    namelist /grid_nml/ corner_deg, step_deg, nlon, nlat

    !-----------------------------------------------------------------

    if (rank == 0) then
       call new_unit(unit)
       open(unit, file = shpc_dir // "/grid_nml.txt", status = "old", &
            action = "read", position = "rewind")
       read(unit, nml = grid_nml)
       close(unit)

       ! As we are requiring the grid spacing to be uniform, the value of
       ! "periodic" may be deduced from the values of step_deg(1) and nlon:
       periodic = nint(360. / step_deg(1)) == nlon
       print *, "periodic = ", periodic

       corner = corner_deg * deg_to_rad
       step = step_deg * deg_to_rad
    end if

#ifndef CPP_SEQUENTIAL
    call ezmpi_bcast(nlon, root = 0)
    call ezmpi_bcast(nlat, root = 0)
    call ezmpi_bcast(periodic, root = 0)
    call ezmpi_bcast(corner, root = 0)
    call ezmpi_bcast(step, root = 0)
#endif

  end subroutine read_grid

end module read_grid_m
